@@ -276,7 +276,7 @@ def _get_service_status_code(instance):
 def _get_service_logs(instance):
     """Get logs for the cfy_manager_install_<type> service."""
     result = instance.run_command(
-        'journalctl status {} 2>&1'.format(instance.unit_name),
+        'journalctl -u {} 2>&1'.format(instance.unit_name),
         use_sudo=True, hide_stdout=True, ignore_failure=True)
     return result.stdout
 
@@ -390,7 +390,7 @@ def _install_instances(instances_dict, verbose):
                 instance.config_path), use_sudo=True)
 
             install_cmd = (
-                'systemd-run -t --unit {unit_name} --uid {user_name} '
+                'systemd-run --unit {unit_name} --uid {user_name} '
                 'cfy_manager install -c {config} {verbose}'.format(
                     config=instance.config_path, unit_name=instance.unit_name,
                     user_name=getuser(), verbose='-v' if verbose else ''))
